<?php

namespace App\Command;

use App\Repository\BlogRepository;
use App\Repository\PageRepository;
use Elastic\Elasticsearch\Client;
use Parsedown;
use Symfony\Component\Console\Attribute\AsCommand;
use Symfony\Component\Console\Command\Command;
use Symfony\Component\Console\Input\InputInterface;
use Symfony\Component\Console\Output\OutputInterface;
use Symfony\Component\Console\Style\SymfonyStyle;

#[AsCommand(
    name: 'app:feed-elasticsearch',
    description: 'Add a short description for your command',
)]
class FeedElasticsearchCommand extends Command
{
    public function __construct(
        private readonly Client $client,
        private readonly PageRepository $pageRepository,
        private readonly BlogRepository $blogRepository,
        private readonly string $elsIndex
    ) {
        parent::__construct();
    }

    protected function configure(): void
    {
        $this
            ->setDescription('Feed Elasticsearch with data');
    }

    protected function execute(InputInterface $input, OutputInterface $output): int
    {
        $io = new SymfonyStyle($input, $output);
        $io->note('Starting indexing of data');
        $this->feedData();
        $io->success('Done Indexing data.');

        return Command::SUCCESS;
    }

    private function feedData(): void
    {
        $parsedown = new Parsedown();
        foreach ($this->pageRepository->findBy(['searchable' => '1']) as $item) {
            $doc = [
                'index' => $this->elsIndex,
                'id' => 'p' . $item->getId(),
                'body' => [
                    'id' => $item->getId(),
                    'title' => $item->getTitle(),
                    'body' => strip_tags($parsedown->text($item->getContent())),
                    'type' => 'page'
                ]
            ];
            $this->client->index($doc);
        }
        foreach ($this->blogRepository->findAll() as $item) {
            $doc = [
                'index' => $this->elsIndex,
                'id' => 'b' . $item->getId(),
                'body' => [
                    'id' => $item->getId(),
                    'title' => $item->getTitle(),
                    'body' => $item->getContent(),
                    'type' => 'blog'
                ]
            ];
            $this->client->index($doc);
        }
    }
}
