<?php

namespace App\Controller;

use App\Repository\BlogRepository;
use Pagerfanta\Doctrine\ORM\QueryAdapter;
use Pagerfanta\Pagerfanta;
use Symfony\Bundle\FrameworkBundle\Controller\AbstractController;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\HttpFoundation\Response;
use Symfony\Component\HttpKernel\Exception\NotFoundHttpException;
use Symfony\Component\Routing\Annotation\Route;

class BlogController extends AbstractController
{
    #[Route('/blog/{id}', methods: ['GET'], name: 'blogEntry')]
    public function getBlogEntry(int $id, BlogRepository $blogRepository): Response
    {
        $blogEntry = $blogRepository->find($id);
        if (!$blogEntry) {
            throw $this->createNotFoundException();
        }
        return $this->render('pages/blog-entry.html.twig', [
            'blog' => $blogEntry
        ]);
    }

    #[Route('/blog', methods: ['GET'], name: 'blog')]
    public function getBlog(BlogRepository $blogRepository, Request $request): Response
    {
        $queryBuilder = $blogRepository->createQueryBuilder('b');
        $queryBuilder->orderBy('b.date', 'DESC');

        $pagination = Pagerfanta::createForCurrentPageWithMaxPerPage(
            new QueryAdapter($queryBuilder),
            (int)$request->query->get('page', '1'),
            20
        );

        return $this->render('pages/blog.html.twig', [
            'pagination' => $pagination,
        ]);
    }
}
