<?php

namespace App\Entity;

use App\Repository\PageRepository;
use Doctrine\Common\Collections\ArrayCollection;
use Doctrine\Common\Collections\Collection;
use Doctrine\DBAL\Types\Types;
use Doctrine\ORM\Mapping as ORM;

#[ORM\Entity(repositoryClass: PageRepository::class)]
class Page
{
    #[ORM\Id]
    #[ORM\GeneratedValue]
    #[ORM\Column]
    private ?int $id = null;

    #[ORM\Column(length: 255)]
    private ?string $path = null;

    #[ORM\Column(type: Types::TEXT)]
    private ?string $content = null;

    #[ORM\Column(length: 255)]
    private ?string $title = null;

    #[ORM\Column(type: Types::DATETIME_MUTABLE)]
    private \DateTimeInterface $createDate;

    #[ORM\OneToMany(mappedBy: 'page', targetEntity: Navigation::class)]
    private Collection $navigations;

    #[ORM\OneToMany(mappedBy: 'page', targetEntity: Comment::class)]
    private Collection $comments;

    #[ORM\Column]
    private bool $commentsEnabled = true;

    #[ORM\Column]
    private ?bool $hasPlaceholder = false;

    #[ORM\Column(length: 255)]
    private ?string $template = 'page';

    #[ORM\Column]
    private ?bool $displayPublishDate = true;

    #[ORM\Column]
    private bool $searchable = true;

    public function __construct()
    {
        $this->createDate = new \DateTimeImmutable();
        $this->navigations = new ArrayCollection();
        $this->comments = new ArrayCollection();
    }

    public function getId(): ?int
    {
        return $this->id;
    }

    public function getPath(): ?string
    {
        return $this->path;
    }

    public function setPath(string $path): self
    {
        $this->path = $path;

        return $this;
    }

    public function getContent(): ?string
    {
        return $this->content;
    }

    public function setContent(string $content): self
    {
        $this->content = $content;

        return $this;
    }

    public function getCreateDate(): ?\DateTimeInterface
    {
        return $this->createDate;
    }

    public function setCreateDate(\DateTimeInterface $createDate): self
    {
        $this->createDate = $createDate;

        return $this;
    }

    public function getTitle(): ?string
    {
        return $this->title;
    }

    public function setTitle(string $title): self
    {
        $this->title = $title;

        return $this;
    }

    /**
     * @return Collection<int, Navigation>
     */
    public function getNavigations(): Collection
    {
        return $this->navigations;
    }

    public function addNavigation(Navigation $navigation): self
    {
        if (!$this->navigations->contains($navigation)) {
            $this->navigations->add($navigation);
            $navigation->setPage($this);
        }

        return $this;
    }

    public function removeNavigation(Navigation $navigation): self
    {
        if ($this->navigations->removeElement($navigation)) {
            // set the owning side to null (unless already changed)
            if ($navigation->getPage() === $this) {
                $navigation->setPage(null);
            }
        }

        return $this;
    }

    /**
     * @return Collection<int, Comment>
     */
    public function getComments(): Collection
    {
        return $this->comments;
    }

    public function addComment(Comment $comment): self
    {
        if (!$this->comments->contains($comment)) {
            $this->comments->add($comment);
            $comment->setPage($this);
        }

        return $this;
    }

    public function removeComment(Comment $comment): self
    {
        if ($this->comments->removeElement($comment)) {
            // set the owning side to null (unless already changed)
            if ($comment->getPage() === $this) {
                $comment->setPage(null);
            }
        }

        return $this;
    }

    public function isCommentsEnabled(): ?bool
    {
        return $this->commentsEnabled;
    }

    public function setCommentsEnabled(bool $commentsEnabled): self
    {
        $this->commentsEnabled = $commentsEnabled;

        return $this;
    }

    public function isHasPlaceholder(): ?bool
    {
        return $this->hasPlaceholder;
    }

    public function setHasPlaceholder(bool $hasPlaceholder): self
    {
        $this->hasPlaceholder = $hasPlaceholder;

        return $this;
    }

    public function getTemplate(): ?string
    {
        return $this->template;
    }

    public function setTemplate(string $template): self
    {
        $this->template = $template;

        return $this;
    }

    public function isDisplayPublishDate(): ?bool
    {
        return $this->displayPublishDate;
    }

    public function setDisplayPublishDate(bool $displayPublishDate): self
    {
        $this->displayPublishDate = $displayPublishDate;

        return $this;
    }

    public function isSearchable(): ?bool
    {
        return $this->searchable;
    }

    public function setSearchable(bool $searchable): self
    {
        $this->searchable = $searchable;

        return $this;
    }
}
