<?php

namespace App\Twig\Components;

use App\Service\ImgProxyService;
use App\Service\S3Service;
use Symfony\UX\TwigComponent\Attribute\AsTwigComponent;
use Symfony\UX\TwigComponent\Attribute\PreMount;

#[AsTwigComponent('image')]
final class ImageComponent
{
    public bool $showLightbox = true;
    public bool $s3File = true;
    public bool $isSkill = false;
    public string $imageFile;
    /**
     * @var array<string, string>
     */
    public array $attributes = [];

    public function __construct(
        private ImgProxyService $imgProxy,
        private S3Service $s3Service,
        private int $imgSkillWidth
    ) {
    }

    /**
     * @param array<string, mixed> $data
     * @return array<string,mixed>
     */
    #[PreMount]
    public function preMount(array $data): array
    {
        if (array_key_exists('isSkill', $data) && $data['isSkill']) {
            $data['attributes']['class'] = 'skills';
        }
        return $data;
    }

    public function getUrl(): string
    {

        if ($this->s3File) {
            return $this->s3Service->generateSignedUrl($this->imageFile);
        }
        return $this->imageFile;
    }

    public function getSmallUrl(): string
    {
        return $this->imgProxy->generateURL($this->getUrl(), $this->isSkill ? $this->imgSkillWidth : null);
    }
}
