<?php

namespace App\Tests\Service;

use PHPUnit\Framework\TestCase;
use Symfony\Contracts\HttpClient\HttpClientInterface;
use Symfony\Contracts\HttpClient\ResponseInterface;

class MailAliasServiceTest extends TestCase
{
    private \App\Service\MailAliasService $service;
    private HttpClientInterface $httpClient;

    protected function setUp(): void
    {
        $this->httpClient = $this->createMock(HttpClientInterface::class);
        $this->service = new \App\Service\MailAliasService(
            "https://mailalias.example.com",
            "test-api-key",
            "test-target-address@example.com",
            $this->httpClient
        );
    }

    public function testGenerateAliasMail(): void
    {
        $expected = "abc@def.de";

        $response = $this->createMock(ResponseInterface::class);
        $response->method('getContent')->willReturn('{"mailAddress": "abc@def.de"}');

        $this->httpClient->expects($this->once())
            ->method('request')
            ->with(
                'POST',
                'https://mailalias.example.com',
                ['json' => [
                    'apikey' => 'test-api-key',
                    'expire' => '4 hours',
                    'targetMail' => 'test-target-address@example.com'
                ]]
            )->willReturn($response);

        $this->assertEquals($expected, $this->service->generateAliasMail());
    }
}